Method: CloudFS::RestAdapter#copy_folder

Defined in:
lib/cloudfs/rest_adapter.rb

#copy_folder(path, destination, name, exists: 'FAIL') ⇒ Hash

Copy folder to specified destination folder

Parameters:

  • path (String)

    source folder path

  • destination (String)

    destination folder path

  • name (String)

    new name of copied folder

  • exists (String) (defaults to: 'FAIL')

    ('FAIL', 'OVERWRITE', 'RENAME') action to take in case of a conflict with an existing folder An unused integer is appended to folder name if exists: RENAME

Returns:

  • (Hash)

    metadata of new folder

Raises:



363
364
365
# File 'lib/cloudfs/rest_adapter.rb', line 363

def copy_folder(path, destination, name, exists: 'FAIL')
  copy(Constants::ENDPOINT_FOLDERS, path, destination, name, exists: exists)
end